User prompt
Make score chart
User prompt
Make enemies disappear when shot
User prompt
Increase player speed by a bunch
User prompt
Make player move faster
User prompt
Make enemy lives decrease by 1 live when hit
User prompt
Make enemies at top of game
User prompt
Delete lightblue block
User prompt
Delete light blue block
User prompt
Please fix the bug: 'ReferenceError: target is not defined' in or related to this line: 'if (fire.intersects(target)) {' Line Number: 136
User prompt
Make blue blocks bad guys
User prompt
Please fix the bug: 'ReferenceError: player is not defined' in or related to this line: 'if (player.intersects(target)) {' Line Number: 118
User prompt
Please fix the bug: 'Uncaught ReferenceError: player is not defined' in or related to this line: 'fire.x = player.x;' Line Number: 97
User prompt
Make a rocket that shoots red fiery bullets
User prompt
Make player have 3 lives
User prompt
Make joystick for player
User prompt
Make a fire breathing monster
Initial prompt
Creeper99iscool
===================================================================
--- original.js
+++ change.js
@@ -12,8 +12,20 @@
self.update = function () {
self.y -= self.speed;
};
});
+// Define the Joystick class
+var Joystick = Container.expand(function () {
+ var self = Container.call(this);
+ var joystickGraphics = self.attachAsset('joystick', {
+ anchorX: 0.5,
+ anchorY: 0.5
+ });
+ self.move = function (x, y) {
+ self.x = x;
+ self.y = y;
+ };
+});
//<Assets used in the game will automatically appear here>
// Define the Player class
var Player = Container.expand(function () {
var self = Container.call(this);
@@ -51,9 +63,9 @@
/****
* Game Code
****/
// Initialize player, target and fire
var player = game.addChild(new Player());
player.x = 2048 / 2;
player.y = 2732 - 200;
var target = game.addChild(new Target());
@@ -61,11 +73,19 @@
target.y = Math.random() * 2732;
var fire = game.addChild(new Fire());
fire.x = player.x;
fire.y = player.y;
+var joystick = game.addChild(new Joystick());
+joystick.x = 200;
+joystick.y = 2732 - 200;
// Handle player movement and fire breathing
game.down = function (x, y, obj) {
- player.move(x, y);
+ joystick.move(x, y);
+ var dx = joystick.x - player.x;
+ var dy = joystick.y - player.y;
+ var angle = Math.atan2(dy, dx);
+ player.x += Math.cos(angle) * player.speed;
+ player.y += Math.sin(angle) * player.speed;
fire.x = player.x;
fire.y = player.y;
};
@@ -51,9 +63,9 @@
* Game Code
****/
-// Initialize player, target and fire
+// Initialize player, target, fire and joystick
var player = game.addChild(new Player());
player.x = 2048 / 2;
// Check for win condition
Red fiery bullet. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.
Monster. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.
Rocket. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.
Space scene that would be good for an app background. Single Game Texture. In-Game asset. 3d. Blank background. High contrast. No shadows.
Bullet dropping downward. Single Game Texture. In-Game asset. 3D. Blank background. High contrast. No shadows.